## 推荐的package结构
pkgname
|- __main__.py
|- pkgname
|  |- __init__.py
|  |- more_source.py
|  |- subpkg1
|  |  |- __init__.py
|  |  |- pkg_code.py
|  |- test
|     |- __init__.py
|     |- test_code.py
|- setup.py

```
python setup.py sdist bdist_wheel

twine upload dist/* 
```